/* traceaxb.c: Generic Mex-C source code for computing the trace of
 * 2 matrix product.
 *
 * Syntax used:
 *				[c] = traceaxb(A,B);
 *
 * Inputs:
 *		A	: Square matrix A
 *		B	: Square matrix B
 *
 * Output:
 *		c	: Trace result of matrix product
 *
 * For use with Matlab version 7.0 (tested) and above. Other versions
 * may be possible, but not tested.
 *
 * Instruction: Run <mex xxx.c> at Matlab command prompt to compile
 * the .c code into .dll (Windows) or .meglx (Linux/UNIX).
 *
 * Initial date on completion of Mex-C code: July 28, 2004.
 * Revised (Improved) date of Mex-C code: November 28,2005.
 *
 *
 * (C) Gaussian Process Toolbox 1.0
 * (C) Copyright 2004-2007, Keith Neo <keith.neo@nuim.ie>
 * 							http://www.hamilton.ie */

#include "mex.h"

void traceaxbc(unsigned long int n,double a[],double b[],double *c)
{
	unsigned long i,j,k;
	c[0]=0.0;
	for(i=0;i<n;i++)
	{
		k=n*i;
		for(j=0;j<n;j++) c[0]=c[0]+a[k+j]*b[n*j+i];
	}
	return;
}

void mexFunction( int nlhs, mxArray *plhs[],
                  int nrhs, const mxArray *prhs[] )
{
	double *C;
	double *A;
	double *B;
	unsigned long int N;

  if(nrhs!=2) {
    mexErrMsgTxt("Two  inputs required.");
  } else if(nlhs>1) {
    mexErrMsgTxt("Too many  output arguments");
  }

  N = mxGetN(prhs[0]);

  plhs[0] = mxCreateDoubleMatrix(1,1, mxREAL);

  A = mxGetPr(prhs[0]);
  B = mxGetPr(prhs[1]);
  C = mxGetPr(plhs[0]);

  traceaxbc(N,A,B,C);
  return;
}
